@@ -228,8 +228,8 @@ class NestedCliCommand(Base):
         """
         self.__parser__.add_argument(*args, **kwargs)
 
-    @staticmethod
-    def register_parser_arguments(parser):
+    # pylint: disable=no-self-use
+    def register_parser_arguments(self, parser):
         """
         Register parser arguments
 
